@@ -1,34 +1,29 @@
 import json
-import os
-from os import path
 import pandas as pd
-import time
 import LibHanger.Library.uwLogger as Logger
-#import chromedriver_binary # コメントアウトしないこと
-from pandas.core.frame import DataFrame 
-from selenium import webdriver
-from selenium.webdriver.android.webdriver import WebDriver
-from selenium.webdriver.chrome.options import Options
-from bs4 import BeautifulSoup
+from pandas.core.frame import DataFrame
+from Scrapinger.Library.browserController import browserContainer
+from Scrapinger.Library.webDriverController import webDriverController
 from mercariGetter.Library.mercariConfig import mercariConfig
-from LibHanger.Library.uwGlobals import *
+from mercariGetter.Library.mercariGetterGlobals import *
 from mercariGetter.Library.mercariException import resultDataGenerateError
-from selenium.webdriver.common.by import By
-#from selenium.webdriver.support.ui import WebDriverWait
-#from selenium.webdriver.support import expected_conditions as EC
 
-class mercariDataSearch:
+class mercariDataSearch(browserContainer):
     
-    def __init__(self):
-
-        """ 
-        コンストラクタ
-        """
-
-        pass
+    """
+    mercariデータ検索クラス
+    """
+    
+    def __init__(self) -> None:
+        
+        # 基底側コンストラクタ
+        super().__init__()
 
+        # WebDriverController
+        self.wdc = webDriverController(gv.mercariGetterConfig, self)
+        
     def searchData(self, searchConditionJsonString:str) -> str:
-
+        
         """
         mercariデータ検索
 
@@ -38,19 +33,80 @@ class mercariDataSearch:
             検索条件Json文字列
 
         """
-
-        # 共通設定取得
-        mc = gv.config
-
+        
         # 取得したメルカリデータをpandas dataframeで返却する
-        dfMercariData = self.getMercariDataToPandas(searchConditionJsonString, mc)
+        dfMercariData = self.getMercariDataToPandas(searchConditionJsonString, gv.mercariGetterConfig)
         
         # pandasデータをjson形式に変換する
         stringJson = dfMercariData.to_json(orient='records')
 
         # jsonデータを返す
         return stringJson
+    
+    def getMercariDataToPandas(self, searchConditionJsonString:str, config:mercariConfig):
+        
+        """
+        取得したmercariデータをpandas dataframeに変換
 
+        Parameters
+        ----------
+        searchConditionJsonString : str
+            検索条件JSON文字列
+        config : mercariConfig
+            共通設定クラス
+        """
+
+        # 検索キーワードと取得する最大ページ数を取得する
+        searchWord, maxPageCount = self.getSearchConditionKeywords(searchConditionJsonString)
+        
+        # 格納用pandasカラム準備
+        dfItemInfo:DataFrame = self.initSearchResultDataColumns()
+        
+        # 検索キーワードが未指定なら処理を抜ける
+        if searchWord == '':
+            return dfItemInfo
+
+        # 検索url
+        url = config.MercariUrl + config.MercariUrlSearch + searchWord
+        
+        # ヘッドレスでブラウザを起動
+        #driver:WebDriver = self.wdc.getWebDriver(config)
+        #driver = self.wdc.browserCtl.getWebDriver()
+        self.wdc.getWebDriverInstance()
+
+        # ウィンドウサイズを1200x1200にする(商品名が省略される為)
+        #self.changeBrowzerSize(driver, '1200', '1000')
+        self.wdc.browserCtl.changeBrowserSize('1200', '1000')
+                
+        # 最大ページ数の数だけループして各ページから取得した結果を結合
+        dictItemInfo:dict = {}
+        for pageNum in range(int(maxPageCount)):
+            
+            # urlの最後にページ番号を付加する
+            pageNum += 1
+            targetUrl = url + '&page={}'.format(str(pageNum))
+
+            # url指定してページ読込
+            #self.loadPage(driver, targetUrl)
+            self.wdc.browserCtl.loadPage(targetUrl)
+            
+            # 検索結果ディクショナリ生成
+            #dictItemInfoTmp:dict = self.createSearchResultDictionary(driver,dfItemInfo, config, len(dictItemInfo))
+            dictItemInfoTmp:dict = self.wdc.browserCtl.createSearchResultDictionary(dfItemInfo, len(dictItemInfo))
+            if len(dictItemInfoTmp) == 0:
+                break
+            else:
+                dictItemInfo.update(dictItemInfoTmp)
+
+            print(len(dictItemInfo))
+            
+        # ブラウザを閉じる
+        self.wdc.browserCtl.wDriver.quit()
+        
+        # pandasデータを返却する
+        #return dfItemInfo if len(dictItemInfo) == 0 else self.createPandasData(dfItemInfo, dictItemInfo)
+        return self.wdc.browserCtl.createPandasData(dfItemInfo, dictItemInfo, ['itemId'])
+    
     def getSearchConditionKeywords(self, searchConditionJsonString:str) -> str:
 
         """
@@ -84,7 +140,7 @@ class mercariDataSearch:
 
         # 検索キーワードを返す
         return keywordsString, maxPageCount
-
+    
     @Logger.loggerDecorator('Init SearchResultData DataFrame')
     def initSearchResultDataColumns(self) -> DataFrame:
         
@@ -97,155 +153,8 @@ class mercariDataSearch:
         """
 
         return pd.DataFrame(columns=['itemId','itemUrl','itemName','itemPrice','itemPicUrl','soldout'])
-
-    @Logger.loggerDecorator('Open Browzer')
-    def getWebDriver(self):
-
-        """
-        ブラウザ操作用のChromeドライバーを取得する
-
-        Parameters
-        ----------
-        None
-        """
-
-        options = Options()
-        options.add_argument('--headless')
-        #return webdriver.Chrome(options=options)
-        driverPath = os.path.join(path.dirname(__file__), 'webDriver','win','chromedriver_win32','chromedriver.exe')
-        return webdriver.Chrome(executable_path=driverPath, options=options)
-
-    @Logger.loggerDecorator('Changing Browzer Size')
-    def changeBrowzerSize(self, driver:WebDriver, width:str, height:str):
-
-        """
-        ブラウザのウィンドウサイズを変更する
-
-        Parameters
-        ----------
-        driver : WebDriver
-            Chromeドライバー
-        width : str
-            ウィンドウ横幅(px)
-        height : str
-            ウィンドウ縦幅(px)
-        """
-
-        # ウィンドウサイズ変更
-        driver.set_window_size(width, height)
-
-    @Logger.loggerDecorator('Loading WebPage')
-    def loadPage(self, driver:WebDriver, url:str):
-
-        """
-        指定URLのページ内容を取得する
-
-        Parameters
-        ----------
-        driver : WebDriver
-            Chromeドライバー
-        url : str
-            ページURL
-        """
-        
-        # ページ内容取得
-        driver.get(url)
-
-    @Logger.loggerDecorator('Delay ')
-    def Delay(self, config:mercariConfig):
-
-        """
-        指定秒数待機する
-
-        Parameters
-        ----------
-        config : mercariConfig
-            共通設定クラス
-        """
-
-        # ログ出力
-        Logger.logging.info('{} Seconds'.format(config.DelayTime))
-
-        # 待機
-        time.sleep(config.DelayTime)
-
-    @Logger.loggerDecorator('WebDriver Delay')
-    def WebDriverWait(self, driver:WebDriver, timeout:int, locater:str, targetElement:str):
-
-        """
-        WebDriverWaitを使った待機及び対象エレメントの取得
-
-        Parameters
-        ----------
-        driver : WebDriver
-            Chromeドライバー
-        timeout : int
-            Webドライバータイムアウト時間(秒)
-        locater : str
-            By.ID,By.CSS_SELECTOR,By.CLASS_NAME,By.TAG_NAME
-        targetElement : str
-            発生するまで待機する要素名
-        """
-
-        # タイムアウト設定
-        driver.implicitly_wait(timeout)
-        # 検索結果エレメント取得
-        element = driver.find_element_by_css_selector(targetElement)
-        
-        return element
-
-    @Logger.loggerDecorator('Create PandasData')
-    def createPandasData(self, dfItemInfo:DataFrame, dictItemInfo:dict) -> DataFrame:
-
-        """
-        ディクショナリからPandasDataFrameを生成する
-
-        Parameters
-        ----------
-        dfItemInfo : DataFrame
-            メルカリデータDataFrame
-        dictItemInfo : dict
-            メルカリデータDictionary
-        """
-
-        # DictionaryをDataFrameに変換
-        dfItemInfo = dfItemInfo.from_dict(dictItemInfo, orient='index')
-
-        # 主キー指定して返す
-        return dfItemInfo.set_index(['itemId'], drop=False)
-
-    @Logger.loggerDecorator('Scraping with BeautifulSoup')
-    def scrapingWithBeautifulSoup(self, driver:WebDriver) -> BeautifulSoup:
-        
-        """
-        BeautifulSoupを使用してスクレイピング
-
-        Parameters
-        ----------
-        driver : WebDriver
-            Chromeドライバー
-        """
-
-        # スクレイピング結果を返す
-        return BeautifulSoup(driver.page_source, features='lxml')
-
-    @Logger.loggerDecorator('Create SearchResultDictionary')
-    def createSearchResultDictionary(self, driver:WebDriver, dfItemInfo:DataFrame, config:mercariConfig, dictItemInfoRowCount:int) -> dict:
-
-        if config.ScrapingType == config.scrapingType.selenium:
-            # 待機
-            element = self.WebDriverWait(driver, config.WebDriverTimeout, By.CSS_SELECTOR, config.DelayWaitElement)
-            # スクレイピング
-            return self.createSearchResultDictionaryByWebDriver(element, dfItemInfo, dictItemInfoRowCount)
-        elif config.ScrapingType == config.scrapingType.beutifulSoup:
-            # 待機
-            self.Delay(config)
-            # スクレイピング
-            soup:BeautifulSoup = self.scrapingWithBeautifulSoup(driver)
-            return self.createSearchResultDictionaryByBeutifulSoup(soup, dfItemInfo, config, dictItemInfoRowCount)
-
-    @Logger.loggerDecorator('Create SearchResultDictionary for Selenium')
-    def createSearchResultDictionaryByWebDriver(self, element, dfItemInfo:DataFrame, dictItemInfoRowCount:int) -> dict:
+    
+    def createSearchResultDictionaryByWebDriver(self, element, dfItemInfo: DataFrame, dictItemInfoRowCount: int) -> dict:
 
         """
         スレイピング結果からDictionaryを生成する
@@ -317,9 +226,7 @@ class mercariDataSearch:
         # 戻り値を返す
         return dictItemInfo
 
-    @Logger.loggerDecorator('Create SearchResultDictionary')
-    def createSearchResultDictionaryByBeutifulSoup(self, soup:BeautifulSoup, dfItemInfo:DataFrame, config:mercariConfig, dictItemInfoRowCount:int) -> dict:
-
+    def createSearchResultDictionaryByBeutifulSoup(self, soup, dfItemInfo: DataFrame, dictItemInfoRowCount: int) -> dict:
         """
         スレイピング結果からDictionaryを生成する
 
@@ -336,7 +243,7 @@ class mercariDataSearch:
         """
 
         # 商品タグ取得
-        elems_items= soup.select(config.ItemTagName)
+        elems_items= soup.select(gv.mercariGetterConfig.ItemTagName)
         
         # 取得した商品タグをループして検索結果ディクショナリを生成
         dictItemInfo = {}
@@ -346,7 +253,7 @@ class mercariDataSearch:
                     # 商品ID
                     itemUrlTmp = elems_items[index].find_all('a')[0].get('href')
                     itemId = itemUrlTmp.split('/')[2]
-                    itemUrl = config.MercariUrl.rstrip('/') + itemUrlTmp
+                    itemUrl = gv.mercariGetterConfig.MercariUrl.rstrip('/') + itemUrlTmp
                     # 商品名
                     itemNm = elems_items[index].find_all('mer-item-thumbnail')[0].get('item-name')
                     # 商品画像URL
@@ -389,61 +296,28 @@ class mercariDataSearch:
         # 戻り値を返す
         return dictItemInfo
 
-    @Logger.loggerDecorator('Get MercariData')
-    def getMercariDataToPandas(self, searchConditionJsonString:str, config:mercariConfig):
+    class chrome(browserContainer.chrome):
         
-        """
-        取得したmercariデータをpandas dataframeに変換
-
-        Parameters
-        ----------
-        searchConditionJsonString : str
-            検索条件JSON文字列
-        config : mercariConfig
-            共通設定クラス
-        """
-
-        # 検索キーワードと取得する最大ページ数を取得する
-        searchWord, maxPageCount = self.getSearchConditionKeywords(searchConditionJsonString)
+        def __init__(self, _config: mercariConfig):
+            super().__init__(_config)
+            #self.cbCreateSearchResultDictionaryByWebDriver = self.createSearchResultDictionaryByWebDriver
+            #self.cbCreateSearchResultDictionaryByBeutifulSoup = self.createSearchResultDictionaryByBeutifulSoup
+            self.cbCreateSearchResultDictionaryByWebDriver = mercariDataSearch.createSearchResultDictionaryByWebDriver
+            self.cbCreateSearchResultDictionaryByBeutifulSoup = mercariDataSearch.createSearchResultDictionaryByBeutifulSoup
         
-        # 格納用pandasカラム準備
-        dfItemInfo:DataFrame = self.initSearchResultDataColumns()
+    class firefox(browserContainer.firefox):
         
-        # 検索キーワードが未指定なら処理を抜ける
-        if searchWord == '':
-            return dfItemInfo
-
-        # 検索url
-        url = config.MercariUrl + config.MercariUrlSearch + searchWord
-        
-        # ヘッドレスでブラウザを起動
-        driver:WebDriver = self.getWebDriver()
-
-        # ウィンドウサイズを1200x1200にする(商品名が省略される為)
-        self.changeBrowzerSize(driver, '1200', '1000')
-
-        # 最大ページ数の数だけループして各ページから取得した結果を結合
-        dictItemInfo:dict = {}
-        for pageNum in range(int(maxPageCount)):
+        def __init__(self, _config: mercariConfig):
+            super().__init__(_config)
+            #self.cbCreateSearchResultDictionaryByWebDriver = self.createSearchResultDictionaryByWebDriver
+            #self.cbCreateSearchResultDictionaryByBeutifulSoup = self.createSearchResultDictionaryByBeutifulSoup
+            self.cbCreateSearchResultDictionaryByWebDriver = mercariDataSearch.createSearchResultDictionaryByWebDriver
+            self.cbCreateSearchResultDictionaryByBeutifulSoup = mercariDataSearch.createSearchResultDictionaryByBeutifulSoup
             
-            # urlの最後にページ番号を付加する
-            pageNum += 1
-            targetUrl = url + '&page={}'.format(str(pageNum))
+        #def createSearchResultDictionaryByWebDriver(self, element, dfItemInfo: DataFrame, dictItemInfoRowCount: int) -> dict:
+        #    print('orverride-createSearchResultDictionaryByWebDriver')
+        #    return super().createSearchResultDictionaryByWebDriver(element, dfItemInfo, dictItemInfoRowCount)
 
-            # url指定してページ読込
-            self.loadPage(driver, targetUrl)
-
-            # 検索結果ディクショナリ生成
-            dictItemInfoTmp:dict = self.createSearchResultDictionary(driver,dfItemInfo, config, len(dictItemInfo))
-            if len(dictItemInfoTmp) == 0:
-                break
-            else:
-                dictItemInfo.update(dictItemInfoTmp)
-
-            print(len(dictItemInfo))
-            
-        # ブラウザを閉じる
-        driver.quit()
-
-        # pandasデータを返却する
-        return dfItemInfo if len(dictItemInfo) == 0 else self.createPandasData(dfItemInfo, dictItemInfo)
+        #def createSearchResultDictionaryByBeutifulSoup(self, soup, dfItemInfo: DataFrame, dictItemInfoRowCount: int) -> dict:
+        #    print('orverride-createSearchResultDictionaryByBeutifulSoup')
+        #    return super().createSearchResultDictionaryByBeutifulSoup(soup, dfItemInfo, dictItemInfoRowCount)
\ No newline at end of file
